==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/pt_PT.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Wizard de arranque inicial",
    "Add your profile information! For example your email is needed to reset your password." : "Adicione a sua informação de perfil. Por exemplo, o seu e-mail é necessário para efectuar a reposição da sua chave.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Adicione informação ao seu perfil! Definir uma image de perfil e um nome completo para facilitar o reconhecimento em todas as funcionalidades.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Adicione informação ao seu perfil! Defina um nome completo para facilitar o reconhecimento em todas as funcionalidades.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Adicione informação ao seu perfil! Defina uma imagem de perfil para facilitar o reconhecimento em todas as funcionalidades.",
    "Get the apps to sync your files" : "Obtenha as aplicações para sincronizar os seus ficheiros",
    "Desktop client" : "Cliente de PC",
    "Android app" : "Aplicação Android",
    "iOS app" : "Aplicação iOS",
    "Connect your calendar" : "Ligar o seu calendário",
    "Connect your contacts" : "Ligar os seus contactos",
    "Access files via WebDAV" : "Aceder aos ficheiros via WebDAV",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Aceda e compartilhe os seus ficheiros, calendários, contactos, correio e muito mais a partir de qualquer dispositivo, nos seus termos",
    "Connect your desktop apps to %s" : "Ligue as suas aplicações de PC para %s",
    "Connect your Calendar" : "Ligar o seu calendário",
    "Connect your Contacts" : "Ligar os seus contactos",
    "Show First Run Wizard again" : "Mostrar novamente Wizard de Arranque Inicial"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/pt_PT.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Wizard de arranque inicial",
    "Add your profile information! For example your email is needed to reset your password." : "Adicione a sua informação de perfil. Por exemplo, o seu e-mail é necessário para efectuar a reposição da sua chave.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Adicione informação ao seu perfil! Definir uma image de perfil e um nome completo para facilitar o reconhecimento em todas as funcionalidades.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Adicione informação ao seu perfil! Defina um nome completo para facilitar o reconhecimento em todas as funcionalidades.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Adicione informação ao seu perfil! Defina uma imagem de perfil para facilitar o reconhecimento em todas as funcionalidades.",
    "Get the apps to sync your files" : "Obtenha as aplicações para sincronizar os seus ficheiros",
    "Desktop client" : "Cliente de PC",
    "Android app" : "Aplicação Android",
    "iOS app" : "Aplicação iOS",
    "Connect your desktop apps to %s" : "Ligue as suas aplicações de PC para %s",
    "Connect your calendar" : "Ligar o seu calendário",
    "Connect your contacts" : "Ligar os seus contactos",
    "Access files via WebDAV" : "Aceder aos ficheiros via WebDAV",
    "Show First Run Wizard again" : "Mostrar novamente Wizard de Arranque Inicial",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Aceda e compartilhe os seus ficheiros, calendários, contactos, correio e muito mais a partir de qualquer dispositivo, nos seus termos"
},
"nplurals=2; plural=(n != 1);");
